jaclearn.rl.algo.advantage
==========================

.. automodule:: jaclearn.rl.algo.advantage

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      AdvantageComputerBase
      DiscountedAdvantageComputer
      GAEComputer
   
   

   
   
   

   
   
   








.. rubric:: Class AdvantageComputerBase
.. autoclass:: AdvantageComputerBase
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class DiscountedAdvantageComputer
.. autoclass:: DiscountedAdvantageComputer
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class GAEComputer
.. autoclass:: GAEComputer
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







